import pandas as pd
import numpy

def integral_difference_norm_steps(stepSizes, series1, series2):
	"""Computes norm of differences between two curves with different y values over same x-step sizes

	Arguments:
	   stepSizes An array with step sizes (weights) for each value
	   series1 A series with values (length equal to length of stepSizes)
	   series2 The other series (length equal to length of stepSizes) to compute difference to.
	"""

	count = len(stepSizes)
	integral_difference = 0
	weightSum = 0
	for i in range(count):
		diff = abs(series1[i] - series2[i])
		weight = float(max(abs(series1[i]), abs(series2[i])))
		weight = max(weight, 1e-10)
		diff = diff/weight; # normalize in value direction
		stepSize = stepSizes[i]
		integral_difference = integral_difference + diff*stepSize
		weightSum = weightSum + stepSize
	return integral_difference / weightSum # normalize over sum of weights


def integral_difference_norm_timepoints(tp, series1, series2):
	"""Computes norm of differences between two curves with different y values over same time points

	Arguments:
	   tp An array with time points for each value
	   series1 A series with values (length equal to length of stepSizes)
	   series2 The other series (length equal to length of stepSizes) to compute difference to.
	"""

	count = len(tp)
	if count != len(series1) or count != len(series2):
		print "Mismatching series count: {},{},{}".format(count, len(series1), len(series2))
		return 1
	integral_difference = 0
	for i in range(count-1):
		diff1 = abs(series1[i] - series2[i])
		weight1 = float(max(abs(series1[i]), abs(series2[i])))
		weight1 = max(weight1, 1e-10)
		diff1 = diff1/weight1; # normalize in value direction

		diff2 = abs(series1[i+1] - series2[i+1])
		weight2 = float(max(abs(series1[i+1]), abs(series2[i+1])))
		weight2 = max(weight2, 1e-10)
		diff2 = diff2/weight2; # normalize in value direction

		stepSize = tp[i+1] - tp[i]
		integral_difference = integral_difference + 0.5*(diff1+diff2)*stepSize
	tpLast = tp[-1]
	return integral_difference / tpLast # normalize over x-range
